@@ -207,7 +207,7 @@ class LazyUser(object):
             try:
                 uid, mac = uhmac.split('$')
                 user = self.db.query(self.User).get(uid)
-                if not user or uhmac != self.get_user_hmac(user):
+                if not user or uhmac != get_user_hmac(user):
                     raise ValueError
             except ValueError:
                 user = None
